# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/mandos.tech/shopee_ali/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/mandos.tech/shopee_ali/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Mandos.tech\\ShopeeAli\\": "packages/mandos.tech/shopee_ali/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Mandos.tech\ShopeeAli\Providers\ShopeeAliServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'ShopeeAli'  => Mandos.tech\ShopeeAli\Facades\ShopeeAli::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Mandos.tech\\ShopeeAliTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Mandos.tech\ShopeeAli\Providers\ShopeeAliServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Mandos.tech\ShopeeAli\Providers\ShopeeAliServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Mandos.tech\ShopeeAli\Providers\ShopeeAliServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/shopee_ali/{modulename}

**User**

    http://path-to-route-folder/user/shopee_ali/{modulename}

**Public**

    http://path-to-route-folder/shopee_alis


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/shopee_ali/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/shopee_ali/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/shopee_ali/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/shopee_ali/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/shopee_ali/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/shopee_ali/{modulename}/{slug}
    METHOD: GET